( cd usr/lib64 ; rm -rf libsqlite3.so )
( cd usr/lib64 ; ln -sf libsqlite3.so.0.8.6 libsqlite3.so )
( cd usr/lib64 ; rm -rf libsqlite3.so.0 )
( cd usr/lib64 ; ln -sf libsqlite3.so.0.8.6 libsqlite3.so.0 )
